From 777b53b564c0d7f1a72870b643013304e85428a0 Mon Sep 17 00:00:00 2001
From: Jean-Paul Calderone <exarkun@twistedmatrix.com>
Date: Mon, 23 Sep 2019 12:34:51 -0400
Subject: [PATCH] Give it a better name considering what it ended up doing

---
 nixos/modules/tests/private-storage.nix | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/nixos/modules/tests/private-storage.nix b/nixos/modules/tests/private-storage.nix
index 98f9c6fd..0a65bf19 100644
--- a/nixos/modules/tests/private-storage.nix
+++ b/nixos/modules/tests/private-storage.nix
@@ -14,8 +14,8 @@ let
     text = introducerFURL;
   };
 
-  # assignAddresses :: Set Name (Set -> AttrSet) -> Set Name (Set -> AttrSet)
-  assignAddresses = nodes:
+  # setupNetwork :: Set Name (Set -> AttrSet) -> Set Name (Set -> AttrSet)
+  setupNetwork = nodes:
     let
       # makeNetwork :: Integer -> AttrSet
       makeNetwork = n: {
@@ -54,7 +54,7 @@ in
 # https://nixos.org/nixos/manual/index.html#sec-nixos-tests
 import <nixpkgs/nixos/tests/make-test.nix> {
 
-  nodes = assignAddresses rec {
+  nodes = setupNetwork rec {
     # Get a machine where we can run a Tahoe-LAFS client node.
     client =
       { config, pkgs, ... }:
-- 
GitLab